==> ulyxex.0.1.0.with-tinyMce.zip: pages/code/translate.php <==
<?php
class Translate {
	public function __construct() {
		$this->s = array(
			"Contact website"				=>array("Contact website","Contacter site","Contactar sitio"),
			"Login"							=>array("Login","Connexion","Connectarse"),
			"Made with Ulyxex"				=>array("Made with Ulyxex","Réalisé avec Ulyxex","Realizado con Ulyxex"),
			"Copyleft Free Art License"		=>array("Copyleft Free Art License","Copyleft Licence Art Libre","Copyleft Licencia Arte Libre"),
			"add article of"				=>array("add article of","ajouter article de","añadir articulo de"),
			"modify article of"				=>array("modify article of","modifier article de","cambiar articulo de"),
			"you can't modify this article" =>array("you can't modify this article","vous ne pouvez pas modifier cet article","no se puede cambiar este articulo"), 
			"articles of"					=>array("articles of","articles de","articulos de"),
			"multiple uploads of"			=>array("multiple uploads of","multiples téléversations de","subir varios ficheros de"),
			"admin home by"					=>array("admin home by","administration accueil","administrar página principal"),
			"add link of"					=>array("add link of","ajouter lien de","añadir link de"),
			"no subject"					=>array("no subject","pas de sujet","sin sujeto"),
            "subject"					    =>array("subject","sujet","sujeto"),
			"article"						=>array("article","article","articulo"),
			"created !"						=>array("created !","créé !","registrado"),
			"hide"							=>array("hide","caché","escondido"),
			"choose page"					=>array("choose page","choisir page","elegir la página"),
			"subject (not displayed only info)"	=>array("subject (not displayed only info)","sujet (non affiché uniquement pour info)","sujeto (no se muestra sólo para info)"),
			"content"						=>array("content","contenu","contenido"),
			"save"							=>array("save","enregistrer","salvar"),
			"admin home"					=>array("admin home","accueil admin","admin Inicio"),
			"articles"						=>array("articles","articles","articulos"),
			"uploads"						=>array("uploads","téléversements","archivos"),
			"pages"							=>array("pages","pages","páginas"),
			"links"							=>array("links","liens","enlaces"),
			"users"							=>array("users","utilisateurs","usuarios"),
			"my user profile"				=>array("my user profile","mon profil utilisateur","mi perfil de usuario"),
			"help"							=>array("help","aide","ayuda"),
			"login"							=>array("login","connexion","entrar"),
			"logout"						=>array("logout","déconnexion","salida"),
			", (some values have been modified !)"	=>array(", (some values have been modified !)",", (certaines valeurs ont été modifiées !)",", (Algunos valores se han modificado!)"),
			"sort/group by"					=>array("sort/group by","trier/grouper by","ordenar/groupo"),
			"search subject"				=>array("search subject","chercher sujet","buscar sujeto"),
			"update all"					=>array("update all","tout mettre à jour","actualizar todo"),
			"{page-SandBox}"				=>array("{page-SandBox}","{page-SandBox}","{página-SandBox}"),
			"modify"						=>array("modify","modifier","cambiar"),
			"delete"						=>array("delete","supprimer","suprimir"),
			"view"							=>array("view","afficher","examinar"),
			"articles list"					=>array("articles list","liste des articles","lista de articulos"),
			"{by-"							=>array("{by-","{par-","{por-"),
            "by-"							=>array("by-","par-","por-"),
			"add article"					=>array("add article","ajouter article","añadir articulo"),
			"update date"					=>array("upadte date","mettre à jour date","actualizar fecha"),
			"update"						=>array("update","mettre à jour","actualizar"),
			"field"							=>array("field","champ","campo"),
			"empty"							=>array("empty","vide","vacío"),
			"uploaded"						=>array("uploaded","téléversé","subido"),
			"upload file"					=>array("upload file","téléverser fichier","subir fichero"),
			"list files"					=>array("list files","liste fichiers","ficheros lista"),
			"not allowed file"				=>array("not allowed file","fichiers interdits","archivos no permitidos"),
			"files allowed:"				=>array("files allowed:","fichiers autorisés","archivos permitidos"),
			"upload files to"				=>array("upload files to","téléverser fichier vers","subir ficheros para"),
			"directory"						=>array("directory","dossier","carpeta"),
			"directories"					=>array("directories","dossiers","carpetas"),
			"files"							=>array("files","fichiers","ficheros"),
			"modify link of"				=>array("modify link of","modifier lien de","modificar enlace de"),
			"links of"						=>array("links of","liens de","enlaces de"),
			"name"							=>array("name","nom","titulo"),
			"link"							=>array("link","lien","enlace"),
			"links list"					=>array("link list","liste liens","lista enlaces"),
			"description"					=>array("description","description","descripción"),
			"search name"					=>array("search name","chercher nom","buscar titulo"),
			"add link"						=>array("add link","ajouter lien","añadir enlace"),
			"linktext"						=>array("linktext","textelien","enlacetexto"),
			"page name in use for home is"	=>array("page name in use for home is","page choisie pour acceuil","página principal"),
			"select home page"				=>array("select home page","choisir accueil","seleccione la página principal"),
			"website administrator mail"	=>array("website administrator mail","mail administrateur","mail administrador"),
			"add page of"					=>array("add page of","ajouter page de","añadir página de"),
			"modify page of"				=>array("modify page of","modifier page de","modificar página de"),
            "pages of"						=>array("pages of","pages de","páginas de"),
			"title"							=>array("title","titre","titulo"),
			"protected"						=>array("protected","protégé","protegido"),
			"add page"						=>array("add page","ajouter page","añadir página"),
			"pages list"					=>array("pages list","pages liste","lista páginas"),
			"add user of"					=>array("add user of","ajoute utilisateur","añadir usuario"),
			"modify user of"				=>array("modify user of","modifier utilisateur de","modificar usuario de"),
			"users of"						=>array("users of","utilisateurs de","usuarios"),
			"user"							=>array("user","utilisateur","usuario"),
			"login"							=>array("login","login","login"),
			"password"						=>array("password","mot de passe","contraseña"),
			"confirm password"				=>array("confirm password","confirmer mot de passe","confirma contraseña"),
			"level"							=>array("level","niveau","nivel"),
			"mail"							=>array("mail","mail","mail"),
			"error password !"				=>array("error password !","erreur mot de passe","error contraseña !"),
			"password empty !"				=>array("password empty !","mot de passe vide !","falta contraseña!"),
			"wrong password or level !"		=>array("wrong password or level !","erreur de mot de passe ou niveau","error de contraseña o nivel !"),
			"login field empty !"			=>array("login field empty !","champ login vide !","no login !"),
			"username field empty !"		=>array("username field empty !","champ utilisateur vide !","no usuario !"),
			"login in use !"				=>array("login in use !","login déjà utilisé","login utilizado"),
			"wrong level !"					=>array("wrong level !","erreur niveau","error nivel"),
			"updated !"						=>array("updated !","mis à jour","actualizado"),
			"level-"						=>array("level-","niveau-","nivel-"),
			"users list"					=>array("users list","liste utilisateurs","lista usuarios"),
			"delete selected"				=>array("delete selected","supprimer sélection","suprimir selección"),
			"add user"						=>array("add user","ajouter utilisateur","añadir usuario"),
			"page"							=>array("page","page","página"),
			"no user !"						=>array("no user !","pas d'utilisateur !","error usuario !"),
			"bad login & password"			=>array("bad login & password","mauvais login & mot de passe","login & contraseña falsos"),
			"no link !"						=>array("no link !","pas de lien !","error enlace !"),
			"no page !"						=>array("no page !","pas de page !","error página !"),
			"contact"						=>array("contact","contact","contacto"),
			"no article !"					=>array("no article !","pas d'article !","error articulo !"),
			"sub page of"					=>array("sub page of","sous page de","sub page of"),
			"login in use !"				=>array("login in use !","login utilisé","login utilizado"),
			"only admin can modify admin !"	=>array("only admin can modify admin !","uniquement admin peut modifier admin","solo admin pode cambiar admin"),
			"date"							=>array("date","date","fecha"),
			"no filters"					 =>array("cancel filters","annuler filtre","limpiar filtro"),
			"bad lineage !"					=>array("bad lineage !","mauvaise filiation !","linaje falso !"),
			"go id"							=>array("go id","aller à id","ir a id"),
			"sort type"						=>array("sort type","classification","clasificación"),
			"reverse date"					=>array("reverse date","date inversée","fecha inversa"),
			"error"							=>array("error","erreur","error"),
			"last articles"					=>array("last articles","deniers articles","ultimos articulos"),
			"last links"					=>array("last links","derniers liens","ultimos enlaces"),
			""								=>array("","",""),
			""								=>array("","",""),
			""								=>array("","",""),
			"End"							=>array("End","Fin","Fin"),
		);
	}
	public function w($str) {
		// simple tranlation
		if (isset($this->s[$str][L])) {
			$result = $this->s[$str][L];
		} else {
			$result = "no translate entry";
		}
		return $result;
	}
	public function ws($str) {
		// translation with space
		if (isset($this->s[$str][L])) {
			$result = $this->s[$str][L]." ";
		} else {
			$result = "no translate entry ";
		}
		return $result;
	}
	public function wsp($str) {
		// translation with space
		if (isset($this->s[$str][L])) {
			$result = " ".$this->s[$str][L];
		} else {
			$result = "no translate entry ";
		}
		return $result;
	}
public function wsb($str) {
		// translation with space
		if (isset($this->s[$str][L])) {
			$result = " ".$this->s[$str][L]." ";
		} else {
			$result = "no translate entry ";
		}
		return $result;
	}
	public function wl($str) {
		// translation with new line
		if (isset($this->s[$str][L])) {
			$result = $this->s[$str][L]."<br />";
		} else {
			$result = "no translate entry<br />";
		}
		return $result;
	}
}
?>

==> ulyxex.0.1.1.with-tinyMce.zip: pages/code/translate.php <==
<?php
class Translate {
	public function __construct() {
		$this->s = array(
			"Contact website"				=>array("Contact website","Contacter site","Contactar sitio"),
			"Login"							=>array("Login","Connexion","Connectarse"),
			"Made with Ulyxex"				=>array("Made with Ulyxex","Réalisé avec Ulyxex","Realizado con Ulyxex"),
			"Copyleft Free Art License"		=>array("Copyleft Free Art License","Copyleft Licence Art Libre","Copyleft Licencia Arte Libre"),
			"add article of"				=>array("add article of","ajouter article de","añadir articulo de"),
			"modify article of"				=>array("modify article of","modifier article de","cambiar articulo de"),
			"you can't modify this article" =>array("you can't modify this article","vous ne pouvez pas modifier cet article","no se puede cambiar este articulo"), 
			"articles of"					=>array("articles of","articles de","articulos de"),
			"multiple uploads of"			=>array("multiple uploads of","multiples téléversations de","subir varios ficheros de"),
			"admin home by"					=>array("admin home by","administration accueil","administrar página principal"),
			"add link of"					=>array("add link of","ajouter lien de","añadir link de"),
			"no subject"					=>array("no subject","pas de sujet","sin sujeto"),
            "subject"					    =>array("subject","sujet","sujeto"),
			"article"						=>array("article","article","articulo"),
			"created !"						=>array("created !","créé !","registrado"),
			"hide"							=>array("hide","caché","escondido"),
			"choose page"					=>array("choose page","choisir page","elegir la página"),
			"subject (not displayed only info)"	=>array("subject (not displayed only info)","sujet (non affiché uniquement pour info)","sujeto (no se muestra sólo para info)"),
			"content"						=>array("content","contenu","contenido"),
			"save"							=>array("save","enregistrer","salvar"),
			"admin home"					=>array("admin home","accueil admin","admin Inicio"),
			"articles"						=>array("articles","articles","articulos"),
			"uploads"						=>array("uploads","téléversements","archivos"),
			"pages"							=>array("pages","pages","páginas"),
			"links"							=>array("links","liens","enlaces"),
			"users"							=>array("users","utilisateurs","usuarios"),
			"my user profile"				=>array("my user profile","mon profil utilisateur","mi perfil de usuario"),
			"help"							=>array("help","aide","ayuda"),
			"login"							=>array("login","connexion","entrar"),
			"logout"						=>array("logout","déconnexion","salida"),
			", (some values have been modified !)"	=>array(", (some values have been modified !)",", (certaines valeurs ont été modifiées !)",", (Algunos valores se han modificado!)"),
			"some values have been modified !"	=>array("some values have been modified !","certaines valeurs ont été modifiées !","Algunos valores se han modificado!"),
			"sort/group by"					=>array("sort/group by","trier/grouper by","ordenar/groupo"),
			"search subject"				=>array("search subject","chercher sujet","buscar sujeto"),
			"update all"					=>array("update all","tout mettre à jour","actualizar todo"),
			"{page-SandBox}"				=>array("{page-SandBox}","{page-SandBox}","{página-SandBox}"),
			"modify"						=>array("modify","modifier","cambiar"),
			"delete"						=>array("delete","supprimer","suprimir"),
			"view"							=>array("view","afficher","examinar"),
			"articles list"					=>array("articles list","liste des articles","lista de articulos"),
			"{by-"							=>array("{by-","{par-","{por-"),
            "by-"							=>array("by-","par-","por-"),
			"add article"					=>array("add article","ajouter article","añadir articulo"),
			"update date"					=>array("upadte date","mettre à jour date","actualizar fecha"),
			"update"						=>array("update","mettre à jour","actualizar"),
			"field"							=>array("field","champ","campo"),
			"empty"							=>array("empty","vide","vacío"),
			"uploaded"						=>array("uploaded","téléversé","subido"),
			"upload file"					=>array("upload file","téléverser fichier","subir fichero"),
			"list files"					=>array("list files","liste fichiers","ficheros lista"),
			"not allowed file"				=>array("not allowed file","fichiers interdits","archivos no permitidos"),
			"files allowed:"				=>array("files allowed:","fichiers autorisés","archivos permitidos"),
			"upload files to"				=>array("upload files to","téléverser fichier vers","subir ficheros para"),
			"directory"						=>array("directory","dossier","carpeta"),
			"directories"					=>array("directories","dossiers","carpetas"),
			"files"							=>array("files","fichiers","ficheros"),
			"modify link of"				=>array("modify link of","modifier lien de","modificar enlace de"),
			"links of"						=>array("links of","liens de","enlaces de"),
			"name"							=>array("name","nom","titulo"),
			"link"							=>array("link","lien","enlace"),
			"links list"					=>array("link list","liste liens","lista enlaces"),
			"description"					=>array("description","description","descripción"),
			"search by name"					=>array("search by name","chercher par nom","buscar con titulo"),
			"add link"						=>array("add link","ajouter lien","añadir enlace"),
			"linktext"						=>array("linktext","textelien","enlacetexto"),
			"page name in use for home is"	=>array("page name in use for home is","page choisie pour acceuil","página principal"),
			"select home page"				=>array("select home page","choisir accueil","seleccione la página principal"),
			"website administrator mail"	=>array("website administrator mail","mail administrateur","mail administrador"),
			"add page of"					=>array("add page of","ajouter page de","añadir página de"),
			"modify page of"				=>array("modify page of","modifier page de","modificar página de"),
            "pages of"						=>array("pages of","pages de","páginas de"),
			"title"							=>array("title","titre","titulo"),
			"protected"						=>array("protected","protégé","protegido"),
			"add page"						=>array("add page","ajouter page","añadir página"),
			"pages list"					=>array("pages list","pages liste","lista páginas"),
			"add user of"					=>array("add user of","ajoute utilisateur","añadir usuario"),
			"modify user of"				=>array("modify user of","modifier utilisateur de","modificar usuario de"),
			"users of"						=>array("users of","utilisateurs de","usuarios"),
			"user"							=>array("user","utilisateur","usuario"),
			"login"							=>array("login","login","login"),
			"password"						=>array("password","mot de passe","contraseña"),
			"confirm password"				=>array("confirm password","confirmer mot de passe","confirma contraseña"),
			"level"							=>array("level","niveau","nivel"),
			"mail"							=>array("mail","mail","mail"),
			"error password !"				=>array("error password !","erreur mot de passe","error contraseña !"),
			"password empty !"				=>array("password empty !","mot de passe vide !","falta contraseña!"),
			"wrong password or level !"		=>array("wrong password or level !","erreur de mot de passe ou niveau","error de contraseña o nivel !"),
			"login field empty !"			=>array("login field empty !","champ login vide !","no login !"),
			"username field empty !"		=>array("username field empty !","champ utilisateur vide !","no usuario !"),
			"login in use !"				=>array("login in use !","login déjà utilisé","login utilizado"),
			"wrong level !"					=>array("wrong level !","erreur niveau","error nivel"),
			"updated !"						=>array("updated !","mis à jour","actualizado"),
			"level-"						=>array("level-","niveau-","nivel-"),
			"users list"					=>array("users list","liste utilisateurs","lista usuarios"),
			"delete selected"				=>array("delete selected","supprimer sélection","suprimir selección"),
			"add user"						=>array("add user","ajouter utilisateur","añadir usuario"),
			"page"							=>array("page","page","página"),
			"no user !"						=>array("no user !","pas d'utilisateur !","error usuario !"),
			"bad login & password"			=>array("bad login & password","mauvais login & mot de passe","login & contraseña falsos"),
			"no link !"						=>array("no link !","pas de lien !","error enlace !"),
			"no page !"						=>array("no page !","pas de page !","error página !"),
			"contact"						=>array("contact","contact","contacto"),
			"no article !"					=>array("no article !","pas d'article !","error articulo !"),
			"sub page of"					=>array("sub page of","sous page de","sub page of"),
			"login in use !"				=>array("login in use !","login utilisé","login utilizado"),
			"only admin can modify admin !"	=>array("only admin can modify admin !","uniquement admin peut modifier admin","solo admin pode cambiar admin"),
			"date"							=>array("date","date","fecha"),
			"no filters"					 =>array("cancel filters","annuler filtre","limpiar filtro"),
			"bad lineage !"					=>array("bad lineage !","mauvaise filiation !","linaje falso !"),
			"go id"							=>array("go id","aller à id","ir a id"),
			"sort type"						=>array("sort type","classification","clasificación"),
			"reverse date"					=>array("reverse date","date inversée","fecha inversa"),
			"error"							=>array("error","erreur","error"),
			"last articles"					=>array("last articles","deniers articles","ultimos articulos"),
			"last links"					=>array("last links","derniers liens","ultimos enlaces"),
			""								=>array("","",""),
			""								=>array("","",""),
			""								=>array("","",""),
			"End"							=>array("End","Fin","Fin"),
		);
	}
	public function w($str) {
		// simple tranlation
		if (isset($this->s[$str][L])) {
			$result = $this->s[$str][L];
		} else {
			$result = "no translate entry";
		}
		return $result;
	}
	public function ws($str) {
		// translation with space
		if (isset($this->s[$str][L])) {
			$result = $this->s[$str][L]." ";
		} else {
			$result = "no translate entry ";
		}
		return $result;
	}
	public function wsp($str) {
		// translation with space
		if (isset($this->s[$str][L])) {
			$result = " ".$this->s[$str][L];
		} else {
			$result = "no translate entry ";
		}
		return $result;
	}
public function wsb($str) {
		// translation with space
		if (isset($this->s[$str][L])) {
			$result = " ".$this->s[$str][L]." ";
		} else {
			$result = "no translate entry ";
		}
		return $result;
	}
	public function wl($str) {
		// translation with new line
		if (isset($this->s[$str][L])) {
			$result = $this->s[$str][L]."<br />";
		} else {
			$result = "no translate entry<br />";
		}
		return $result;
	}
}
?>
